@@ -53,6 +53,34 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateDBInstances(self, request):
+        """This API is used to create one or more TencentDB for PostgreSQL instances.
+
+        :param request: Request instance for CreateDBInstances.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.CreateDBInstancesRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.CreateDBInstancesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateDBInstances", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateDBInstancesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeAccounts(self, request):
         """This API is used to get the instance user list.
 
@@ -165,6 +193,34 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeDBInstances(self, request):
+        """This API is used to query the details of one or more instances.
+
+        :param request: Request instance for DescribeDBInstances.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.DescribeDBInstancesRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.DescribeDBInstancesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeDBInstances", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeDBInstancesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeDBSlowlogs(self, request):
         """This API is used to get slow query logs.
 
@@ -550,6 +606,34 @@ class PostgresClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def UpgradeDBInstance(self, request):
+        """This API is used to upgrade an instance.
+
+        :param request: Request instance for UpgradeDBInstance.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.UpgradeDBInstanceRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.UpgradeDBInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("UpgradeDBInstance", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.UpgradeDBInstanceResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
